from kbrainsdk.validation.ingest import validate_ingest_onedrive, validate_ingest_sharepoint, validate_ingest_status
from kbrainsdk.apibase import APIBase

class Ingest(APIBase):

    def ingest_onedrive(self, email, token, client_id, oauth_secret, tenant_id, environment):

        payload = {
            "email": email,
            "token": token,
            "environment": environment,
            "client_id": client_id,
            "oauth_secret": oauth_secret,
            "tenant_id": tenant_id
        }

        validate_ingest_onedrive(payload)

        path = f"/ingest/onedrive/v1"
        response = self.apiobject.call_endpoint(path, payload, "post")
        return response

    def ingest_sharepoint(self, host, site, token, client_id, oauth_secret, tenant_id, environment):

        payload = {
            "host": host,
            "site": site,
            "token": token,
            "environment": environment,
            "client_id": client_id,
            "oauth_secret": oauth_secret,
            "tenant_id": tenant_id
        }

        validate_ingest_sharepoint(payload)

        path = f"/ingest/sharepoint/v1"
        response = self.apiobject.call_endpoint(path, payload, "post")
        return response

    def get_status(self, datasource):

        payload = {
            "datasource": datasource 
        }

        validate_ingest_status(payload)

        path = f"/ingest/status/v1"
        response = self.apiobject.call_endpoint(path, payload, "post")
        return response

    def convert_email_to_datasource(self, email):
        return f"drive-{email.lower().replace('@', '-at-').replace('.', '-')}"



from kbrainsdk.validation.common import get_payload

DECIDE_ARGUMENTS = ["query", "choices", "examples", "argument_temperature", "decision_temperature"]
DECIDE_MANDATORY_ARGUMENTS = ["query", "choices", "examples"]

def validate_ai_decide(req):
    payload = get_payload(req)
    log_payload = {key: payload[key] for key in DECIDE_ARGUMENTS if (key in payload and payload[key] is not None)}

    # Check if mandatory values are present
    missing_values = [value for value in DECIDE_MANDATORY_ARGUMENTS if value not in log_payload]
    if missing_values:
        raise ValueError("Missing or empty parameter in request body. Requires: {}".format(", ".join(missing_values)))

    if not all(isinstance(choice, dict) and 'label' in choice and 'description' in choice for choice in log_payload['choices']):
        raise ValueError("'choices' must be a list of objects with properties 'label' and 'description'")

    if not all(isinstance(example, dict) and 'query' in example and 'argument' in example and 'decision' in example for example in log_payload['examples']):
        raise ValueError("'examples' must be a list of objects with properties 'query', 'argument', and 'decision'")

    return log_payload


from kbrainsdk.validation.common import get_payload, validate_email

def validate_list_datasets(req):
    body = get_payload(req)
    email = body.get('email')
    token = body.get('token')
    client_id = body.get('client_id')
    oauth_secret = body.get('oauth_secret')
    tenant_id = body.get('tenant_id')

 # Validate parameters
    if not all([email, token, client_id, oauth_secret, tenant_id]):
        raise ValueError("Missing or empty parameter in request body")

    if not validate_email(email):
        raise ValueError("Invalid email address")
    
    return email, token, client_id, oauth_secret, tenant_id
